@@ -1,5 +1,7 @@
 #[cfg(feature = "modules")]
 pub mod helper;
+#[cfg(feature = "mock")]
+pub mod mock;
 mod reader;
 
 pub use crate::reader::ReadError;
@@ -9,7 +11,7 @@ use std::collections::HashMap;
 use std::convert::TryFrom;
 use std::fs;
 use std::io::Error as IoError;
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 
 #[derive(Debug)]
 pub enum BuildError {
@@ -79,7 +81,6 @@ impl Domain {
 }
 
 #[derive(Debug)]
-#[cfg_attr(feature = "with-serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct DomainSnapshot {
     pub id: u8,
     pub name: String,
@@ -173,7 +174,6 @@ impl Socket {
 }
 
 #[derive(Debug)]
-#[cfg_attr(feature = "with-serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct SocketSnapshot {
     pub id: u8,
     pub enabled: bool,
@@ -238,7 +238,6 @@ impl IntelRapl {
 }
 
 #[derive(Debug)]
-#[cfg_attr(feature = "with-serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct IntelRaplSnapshot {
     pub sockets: Vec<SocketSnapshot>,
 }
@@ -267,13 +266,29 @@ impl TryFrom<PathBuf> for PowerCap {
     }
 }
 
-#[cfg(test)]
+impl TryFrom<&Path> for PowerCap {
+    type Error = BuildError;
+
+    /// Creates a PowerCap instance using the speficied powercap path.
+    fn try_from(value: &Path) -> Result<Self, Self::Error> {
+        Ok(Self {
+            intel_rapl: IntelRapl::try_from(value.join("intel-rapl"))?,
+        })
+    }
+}
+
+#[cfg(all(test, feature = "mock"))]
 mod tests {
     use super::PowerCap;
+    use crate::mock::MockBuilder;
+    use std::convert::TryFrom;
+    use temp_dir::TempDir;
 
     #[test]
     fn build_and_measure() {
-        let cap = PowerCap::try_default().unwrap();
+        let root = TempDir::new().unwrap();
+        MockBuilder::default().build(root.path()).unwrap();
+        let cap = PowerCap::try_from(root.path()).unwrap();
         let value = cap.intel_rapl.total_energy().unwrap();
         assert_ne!(value, 0);
         for socket in cap.intel_rapl.sockets.values() {
